@@ -24,7 +24,6 @@ async def methods_test():
         # is_active
         is_active = await async_client.is_active_async()
         print(f"is_active: {is_active}")
-
         # sampling factors
         sampling_factors = await async_client.get_sampling_factors_async()
         print(f"sampling_factors: {sampling_factors}")
@@ -59,7 +58,9 @@ async def methods_test():
             ],
         }
         suggested_config = (
-            await async_client.get_suggested_config_from_user_input_async(events, event_loop=loop, executor=executor)
+            await async_client.get_suggested_config_from_user_input_async(
+                events, event_loop=loop, executor=executor
+            )
         )
         print(f"suggested_config: {suggested_config}")
         mona_messages = [
@@ -88,11 +89,11 @@ async def methods_test():
             ),
         ]
         # export (Single msg)
-        #export_res = await async_client.export_async(mona_messages[0])
-        #print(f"export res: {export_res}")
+        # export_res = await async_client.export_async(mona_messages[0])
+        # print(f"export res: {export_res}")
         # export batch
-        #export_batch_res = await async_client.export_batch_async(mona_messages)
-        #print(f"export batch res: {export_batch_res}")
+        # export_batch_res = await async_client.export_batch_async(mona_messages)
+        # print(f"export batch res: {export_batch_res}")
 
         config = async_client.get_config()
         print(f"get_config res: {config}")
@@ -190,7 +191,7 @@ async def methods_test():
     print("... Done!")
 
 
-#asyncio.run(methods_test())
+# asyncio.run(methods_test())
 from random import randint
 
 # Es monitor test
@@ -198,6 +199,7 @@ client_id = "e8018061-0559-4b22-b041-f10ef5848cd6"
 secret_key = "9df5eefb-de6d-4529-b79a-60b398353449"
 
 CONTEXT_CLASSES = [
+    "SMADAR_TEST_ASYNC",
     "SMADAR_TEST_IN_CONFIG_SAMPLED",
     "SMADAR_TEST_IN_CONFIG_SAMPLED_NOT_TAKEN",
     "SMADAR_TEST_TAKES_DEFAULT",
@@ -230,28 +232,32 @@ async def time_test():
         for i in range(NUMBER_OF_MESSAGES_PER_CONTEXT_CLASS):
             messages.append(
                 MonaSingleMessage(
-                    message={"sampled": i},
+                    message={"async_test": i},
                     contextClass=context_class,
                     contextId=str(random_with_N_digits(10)),
                 )
             )
         messages_list.append(messages)
+    loop = asyncio.get_event_loop()
     start_time = time.time()
     for messages in messages_list:
-        coroutines.append(asyncio.create_task(mona_client.export_batch_async(messages)))
-    #original_pokemon = await asyncio.gather(*coroutines)
-    print("--- %s seconds ---" % (time.time() - start_time))
+        coroutines.append(
+            asyncio.create_task(
+                mona_client.export_batch_async(messages, event_loop=loop)
+            )
+        )
+    # coroutines.append(asyncio.create_task(mona_client.export_batch_async(messages_list[0])))
+    # res = await mona_client.export_batch_async(messages_list[0], event_loop=loop)
+    # original_pokemon = await asyncio.gather(*coroutines)
+
+    print(f"--- {(time.time() - start_time)} seconds ---")
 
 
-
-#asyncio.run(methods_test())
+# asyncio.run(methods_test())
 
 
-#start_time = time.time()
+# start_time = time.time()
 
 asyncio.run(time_test())
 
-#print("--- %s seconds ---" % (time.time() - start_time))
-
-
-
+# print("--- %s seconds ---" % (time.time() - start_time))
